<?php

namespace App\Repository;

use App\Entity\MemberCase;
use App\Entity\Referral;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Persistence\ManagerRegistry;

/**
 * @extends ServiceEntityRepository<Referral>
 */
class ReferralRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Referral::class);
    }

    public function getActiveReferrals(MemberCase $case): array
    {
        return $this->createQueryBuilder('r')
            ->andWhere('r.dischargeDate IS NULL')
            ->andWhere('r.memberCase = :case')
            ->setParameter('case', $case->getId()->toBinary())
            ->orderBy('r.hours', 'ASC')
            ->getQuery()
            ->getResult()
        ;
    }

    public function getClosedReferrals(MemberCase $case): array
    {
        return $this->createQueryBuilder('r')
            ->andWhere('r.dischargeDate IS NOT NULL')
            ->andWhere('r.memberCase = :case')
            ->setParameter('case', $case->getId()->toBinary())
            ->orderBy('r.dischargeDate', 'DESC')
            ->getQuery()
            ->getResult()
        ;
    }

    //    /**
    //     * @return Referral[] Returns an array of Referral objects
    //     */
    //    public function findByExampleField($value): array
    //    {
    //        return $this->createQueryBuilder('r')
    //            ->andWhere('r.exampleField = :val')
    //            ->setParameter('val', $value)
    //            ->orderBy('r.id', 'ASC')
    //            ->setMaxResults(10)
    //            ->getQuery()
    //            ->getResult()
    //        ;
    //    }

    //    public function findOneBySomeField($value): ?Referral
    //    {
    //        return $this->createQueryBuilder('r')
    //            ->andWhere('r.exampleField = :val')
    //            ->setParameter('val', $value)
    //            ->getQuery()
    //            ->getOneOrNullResult()
    //        ;
    //    }
}
